==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/hal/translations/hal_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="30"/>
        <source>HAL Plugin</source>
        <translation>HAL 插件</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="50"/>
        <source>About HAL Plugin</source>
        <translation>關於 HAL 插件</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Qmmp HAL 插件</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>此插件利用 HAL 提供可移動設備的檢測</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>基於 Solid (KDE 硬件程式庫)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="161"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>添加 CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="167"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>添加卷 &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL 插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>CD 音頻檢測</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>自動添加音軌到播放清單</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>自動從播放清單刪除音軌</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>可移動設備檢測</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>自動添加檔案到播放清單</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>自動從播放清單刪除檔案</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/hal/translations/hal_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="32"/>
        <source>HAL Plugin</source>
        <translation>HAL 外掛</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>About HAL Plugin</source>
        <translation>關於 HAL 外掛</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Qmmp HAL 外掛</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>此插件利用 HAL 提供可移動設備的檢測</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="56"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>基於 Solid (KDE 硬件程式庫)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>添加 CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>添加卷 &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL 插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>CD 音頻檢測</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>自動添加音軌到播放清單</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>自動從播放清單刪除音軌</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>可移動設備檢測</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>自動添加檔案到播放清單</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>自動從播放清單刪除檔案</translation>
    </message>
</context>
</TS>
